summaryrefslogtreecommitdiffstats
path: root/webkit/plugins/ppapi/plugin_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/plugins/ppapi/plugin_delegate.h')
-rw-r--r--webkit/plugins/ppapi/plugin_delegate.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/webkit/plugins/ppapi/plugin_delegate.h b/webkit/plugins/ppapi/plugin_delegate.h
index 6349cd9..62ad9c1 100644
--- a/webkit/plugins/ppapi/plugin_delegate.h
+++ b/webkit/plugins/ppapi/plugin_delegate.h
@@ -328,9 +328,10 @@ class PluginDelegate {
webkit::ppapi::PPB_Flash_NetConnector_Impl* connector,
const struct PP_Flash_NetAddress* addr) = 0;
// Show the given context menu at the given position (in the render view's
// coordinates).
virtual int32_t ShowContextMenu(
+ PluginInstance* instance,
webkit::ppapi::PPB_Flash_Menu_Impl* menu,
const gfx::Point& position) = 0;
@@ -328,9 +328,10 @@ class PluginDelegate {
webkit::ppapi::PPB_Flash_NetConnector_Impl* connector,
const struct PP_Flash_NetAddress* addr) = 0;
- // Show the given context menu at the given position (in the render view's
+ // Show the given context menu at the given position (in the plugin's
// coordinates).
virtual int32_t ShowContextMenu(